#  Copyright 2019 - Nokia Corporation
#
#  Licensed under the Apache License, Version 2.0 (the "License"); you may
#  not use this file except in compliance with the License. You may obtain
#  a copy of the License at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#  WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#  License for the specific language governing permissions and limitations
#  under the License.

import cotyledon

from vitrage.coordination.coordination import Coordinator


class Service(cotyledon.Service):

    def __init__(self, worker_id):
        super(Service, self).__init__(worker_id)
        self.coordinator = Coordinator('%s_worker_%s' % (self.name,
                                                         worker_id))

    def run(self):
        self.coordinator.start()
        self.coordinator.join_group()

    def terminate(self):
        self.coordinator.stop()
